package com.ruoyi.szxc.mapper;

import java.util.List;
import com.ruoyi.szxc.domain.SzxcNews;

/**
 * 公告资讯Mapper接口
 * 
 * @author hs
 * @date 2024-03-16
 */
public interface SzxcNewsMapper 
{
    /**
     * 查询公告资讯
     * 
     * @param id 公告资讯主键
     * @return 公告资讯
     */
    public SzxcNews selectSzxcNewsById(Long id);

    /**
     * 查询公告资讯列表
     * 
     * @param szxcNews 公告资讯
     * @return 公告资讯集合
     */
    public List<SzxcNews> selectSzxcNewsList(SzxcNews szxcNews);

    /**
     * 新增公告资讯
     * 
     * @param szxcNews 公告资讯
     * @return 结果
     */
    public int insertSzxcNews(SzxcNews szxcNews);

    /**
     * 修改公告资讯
     * 
     * @param szxcNews 公告资讯
     * @return 结果
     */
    public int updateSzxcNews(SzxcNews szxcNews);

    /**
     * 删除公告资讯
     * 
     * @param id 公告资讯主键
     * @return 结果
     */
    public int deleteSzxcNewsById(Long id);

    /**
     * 批量删除公告资讯
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSzxcNewsByIds(Long[] ids);
}
